prompt --application/set_environment
set define off verify off feedback off
whenever sqlerror exit sql.sqlcode rollback
--------------------------------------------------------------------------------
--
-- ORACLE Application Express (APEX) export file
--
-- You should run the script connected to SQL*Plus as the Oracle user
-- APEX_180200 or as the owner (parsing schema) of the application.
--
-- NOTE: Calls to apex_application_install override the defaults below.
--
--------------------------------------------------------------------------------
begin
wwv_flow_api.import_begin (
 p_version_yyyy_mm_dd=>'2018.05.24'
,p_release=>'18.2.0.00.12'
,p_default_workspace_id=>16521107144529159682
,p_default_application_id=>79291
,p_default_owner=>'SDEMBELE'
);
end;
/
prompt --application/shared_components/plugins/item_type/apex_mask_plugin
begin
wwv_flow_api.create_plugin(
 p_id=>wwv_flow_api.id(20929074087395259260)
,p_plugin_type=>'ITEM TYPE'
,p_name=>'APEX MASK PLUGIN'
,p_display_name=>'APEX Mask Plugin'
,p_supported_ui_types=>'DESKTOP:JQM_SMARTPHONE'
,p_supported_component_types=>'APEX_APPLICATION_PAGE_ITEMS:APEX_APPL_PAGE_IG_COLUMNS'
,p_plsql_code=>wwv_flow_string.join(wwv_flow_t_varchar2(
'PROCEDURE render_mask(',
'  p_item   in apex_plugin.t_item,',
'  p_plugin in apex_plugin.t_plugin,',
'  p_param  in apex_plugin.t_item_render_param,',
'  p_result in out nocopy apex_plugin.t_item_render_result)',
'AS',
'  v_result          apex_plugin.t_page_item_render_result;',
'  v_function        varchar2(128);',
'  v_function2       varchar2(128);',
'  v_js_var          varchar2(128);',
'  v_mask            p_item.attribute_01%TYPE := p_item.attribute_01; -- mask',
'  v_reverse         p_item.attribute_02%TYPE := p_item.attribute_02; -- reverse',
'  v_clearIfNotMatch p_item.attribute_03%TYPE := p_item.attribute_03; -- clearIfNotMatch',
'  v_selectOnFocus   p_item.attribute_05%TYPE := (p_item.attribute_04); -- selectOnFocus',
'  v_custom_att      p_item.attribute_05%TYPE := (p_item.attribute_05); -- custom attribute',
'BEGIN',
'  v_reverse         := case when v_reverse <> ''N'' then ''true'' else ''false'' end;',
'  v_clearIfNotMatch := case when v_clearIfNotMatch <> ''N'' then ''true'' else ''false'' end;',
'  v_selectOnFocus   := case when v_selectOnFocus <> ''N'' then ''true'' else ''false'' end;',
'  if v_custom_att is not null then',
'    v_custom_att := '',''||v_custom_att;',
'  end if;    ',
'  -- Load JS Libraries',
'  apex_javascript.add_library (p_name => ''jquery.mask'', p_directory => p_plugin.file_prefix, p_version => null, p_check_to_add_minified => true);',
'  ',
'  -- Input item',
'    sys.htp.prn(''<input'');',
'    sys.htp.prn('' type="text"'');',
'    sys.htp.prn('' id="'' || p_item.name || ''"'');',
'    sys.htp.prn('' name="'' || p_item.name || ''"'');',
'    sys.htp.prn('' class="apex-item-text ''|| p_item.element_css_classes || ''"'');',
'    sys.htp.prn(case when p_item.is_required then '' required'' else null end);',
'    sys.htp.prn('' size="'' || p_item.element_width || ''"'');',
'    sys.htp.prn('' placeholder="'' || p_item.placeholder || ''"'');',
'    sys.htp.prn('' value="'');',
'    sys.htp.prn(p_param.value);',
'    sys.htp.prn(''"'');',
'    sys.htp.prn(''/>'');',
'',
'    -- Run onLoad code',
'    apex_javascript.add_onload_code (p_code =>',
'        ''$(''''#''|| p_item.name ||'''''').mask(''''''||v_mask||'''''',{                              ',
'	                                 reverse: ''||v_reverse||'',',
'									 clearIfNotMatch: ''||v_clearIfNotMatch||'',',
'									 selectOnFocus: ''||v_selectOnFocus||''',
'                                     ''||v_custom_att||''',
'                                     }',
'		);''',
'      );',
'END;'))
,p_api_version=>2
,p_render_function=>'render_mask'
,p_standard_attributes=>'VISIBLE:FORM_ELEMENT:READONLY:SOURCE:ELEMENT:WIDTH:HEIGHT:ELEMENT_OPTION:PLACEHOLDER'
,p_substitute_attributes=>true
,p_subscribe_plugin_settings=>true
,p_help_text=>wwv_flow_string.join(wwv_flow_t_varchar2(
'This plug-in allows to specify a mask for the fields of a form.',
'',
'Use case:',
'Use this plug-in for type masks',
'Date <b>00/00/0000</b>',
'Date Time <b>00/00/0000 00:00:00</b>',
'IP Address <b>0ZZ.0ZZ.0ZZ.0ZZ</b>',
'You can use it to prevent the user from entering numbers only for example.',
'To enter a valid phone number'))
,p_version_identifier=>'1.0'
,p_about_url=>'https://apex.oracle.com/pls/apex/f?p=79291:LOGIN_DESKTOP'
,p_files_version=>2
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(20929131682908278639)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>1
,p_display_sequence=>10
,p_prompt=>'Mask'
,p_attribute_type=>'TEXT'
,p_is_required=>true
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(20932772425508477997)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>2
,p_display_sequence=>20
,p_prompt=>'Reverse'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'N'
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(20933121739116490345)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>3
,p_display_sequence=>30
,p_prompt=>'Clear if not match'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'N'
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(20933854169515498552)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>4
,p_display_sequence=>40
,p_prompt=>'select on focus'
,p_attribute_type=>'CHECKBOX'
,p_is_required=>false
,p_default_value=>'N'
,p_is_translatable=>false
);
wwv_flow_api.create_plugin_attribute(
 p_id=>wwv_flow_api.id(20936577385067782811)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_attribute_scope=>'COMPONENT'
,p_attribute_sequence=>5
,p_display_sequence=>50
,p_prompt=>'Custom attribute'
,p_attribute_type=>'TEXTAREA'
,p_is_required=>false
,p_is_translatable=>false
);
end;
/
begin
wwv_flow_api.g_varchar2_table := wwv_flow_api.empty_varchar2_table;
wwv_flow_api.g_varchar2_table(1) := '2F2F206A5175657279204D61736B20506C7567696E2076312E31342E31350A2F2F206769746875622E636F6D2F69676F726573636F6261722F6A51756572792D4D61736B2D506C7567696E0A76617220246A73636F6D703D7B73636F70653A7B7D2C6669';
wwv_flow_api.g_varchar2_table(2) := '6E64496E7465726E616C3A66756E6374696F6E28612C6C2C64297B6120696E7374616E63656F6620537472696E67262628613D537472696E67286129293B666F722876617220703D612E6C656E6774682C683D303B683C703B682B2B297B76617220623D';
wwv_flow_api.g_varchar2_table(3) := '615B685D3B6966286C2E63616C6C28642C622C682C61292972657475726E7B693A682C763A627D7D72657475726E7B693A2D312C763A766F696420307D7D7D3B246A73636F6D702E646566696E6550726F70657274793D2266756E6374696F6E223D3D74';
wwv_flow_api.g_varchar2_table(4) := '7970656F66204F626A6563742E646566696E6550726F706572746965733F4F626A6563742E646566696E6550726F70657274793A66756E6374696F6E28612C6C2C64297B696628642E6765747C7C642E736574297468726F77206E657720547970654572';
wwv_flow_api.g_varchar2_table(5) := '726F72282245533320646F6573206E6F7420737570706F7274206765747465727320616E6420736574746572732E22293B61213D41727261792E70726F746F74797065262661213D4F626A6563742E70726F746F74797065262628615B6C5D3D642E7661';
wwv_flow_api.g_varchar2_table(6) := '6C7565297D3B0A246A73636F6D702E676574476C6F62616C3D66756E6374696F6E2861297B72657475726E22756E646566696E656422213D747970656F662077696E646F77262677696E646F773D3D3D613F613A22756E646566696E656422213D747970';
wwv_flow_api.g_varchar2_table(7) := '656F6620676C6F62616C26266E756C6C213D676C6F62616C3F676C6F62616C3A617D3B246A73636F6D702E676C6F62616C3D246A73636F6D702E676574476C6F62616C2874686973293B246A73636F6D702E706F6C7966696C6C3D66756E6374696F6E28';
wwv_flow_api.g_varchar2_table(8) := '612C6C2C642C70297B6966286C297B643D246A73636F6D702E676C6F62616C3B613D612E73706C697428222E22293B666F7228703D303B703C612E6C656E6774682D313B702B2B297B76617220683D615B705D3B6820696E20647C7C28645B685D3D7B7D';
wwv_flow_api.g_varchar2_table(9) := '293B643D645B685D7D613D615B612E6C656E6774682D315D3B703D645B615D3B6C3D6C2870293B6C213D7026266E756C6C213D6C2626246A73636F6D702E646566696E6550726F706572747928642C612C7B636F6E666967757261626C653A21302C7772';
wwv_flow_api.g_varchar2_table(10) := '697461626C653A21302C76616C75653A6C7D297D7D3B0A246A73636F6D702E706F6C7966696C6C282241727261792E70726F746F747970652E66696E64222C66756E6374696F6E2861297B72657475726E20613F613A66756E6374696F6E28612C64297B';
wwv_flow_api.g_varchar2_table(11) := '72657475726E20246A73636F6D702E66696E64496E7465726E616C28746869732C612C64292E767D7D2C226573362D696D706C222C2265733322293B0A2866756E6374696F6E28612C6C2C64297B2266756E6374696F6E223D3D3D747970656F66206465';
wwv_flow_api.g_varchar2_table(12) := '66696E652626646566696E652E616D643F646566696E65285B226A7175657279225D2C61293A226F626A656374223D3D3D747970656F66206578706F7274733F6D6F64756C652E6578706F7274733D61287265717569726528226A71756572792229293A';
wwv_flow_api.g_varchar2_table(13) := '61286C7C7C64297D292866756E6374696F6E2861297B766172206C3D66756E6374696F6E28622C652C66297B76617220633D7B696E76616C69643A5B5D2C67657443617265743A66756E6374696F6E28297B7472797B76617220612C723D302C673D622E';
wwv_flow_api.g_varchar2_table(14) := '6765742830292C653D646F63756D656E742E73656C656374696F6E2C663D672E73656C656374696F6E53746172743B6966286526262D313D3D3D6E6176696761746F722E61707056657273696F6E2E696E6465784F6628224D534945203130222929613D';
wwv_flow_api.g_varchar2_table(15) := '652E63726561746552616E676528292C612E6D6F766553746172742822636861726163746572222C2D632E76616C28292E6C656E677468292C723D612E746578742E6C656E6774683B656C736520696628667C7C2230223D3D3D6629723D663B72657475';
wwv_flow_api.g_varchar2_table(16) := '726E20727D63617463682843297B7D7D2C73657443617265743A66756E6374696F6E2861297B7472797B696628622E697328223A666F6375732229297B76617220632C0A673D622E6765742830293B672E73657453656C656374696F6E52616E67653F67';
wwv_flow_api.g_varchar2_table(17) := '2E73657453656C656374696F6E52616E676528612C61293A28633D672E6372656174655465787452616E676528292C632E636F6C6C61707365282130292C632E6D6F7665456E642822636861726163746572222C61292C632E6D6F766553746172742822';
wwv_flow_api.g_varchar2_table(18) := '636861726163746572222C61292C632E73656C6563742829297D7D63617463682842297B7D7D2C6576656E74733A66756E6374696F6E28297B622E6F6E28226B6579646F776E2E6D61736B222C66756E6374696F6E2861297B622E6461746128226D6173';
wwv_flow_api.g_varchar2_table(19) := '6B2D6B6579636F6465222C612E6B6579436F64657C7C612E7768696368293B622E6461746128226D61736B2D707265766975732D76616C7565222C622E76616C2829293B622E6461746128226D61736B2D707265766975732D63617265742D706F73222C';
wwv_flow_api.g_varchar2_table(20) := '632E67657443617265742829293B632E6D61736B4469676974506F734D61704F6C643D632E6D61736B4469676974506F734D61707D292E6F6E28612E6A4D61736B476C6F62616C732E757365496E7075743F22696E7075742E6D61736B223A226B657975';
wwv_flow_api.g_varchar2_table(21) := '702E6D61736B222C632E6265686176696F7572292E6F6E282270617374652E6D61736B2064726F702E6D61736B222C66756E6374696F6E28297B73657454696D656F75742866756E6374696F6E28297B622E6B6579646F776E28292E6B6579757028297D';
wwv_flow_api.g_varchar2_table(22) := '2C0A313030297D292E6F6E28226368616E67652E6D61736B222C66756E6374696F6E28297B622E6461746128226368616E676564222C2130297D292E6F6E2822626C75722E6D61736B222C66756E6374696F6E28297B643D3D3D632E76616C28297C7C62';
wwv_flow_api.g_varchar2_table(23) := '2E6461746128226368616E67656422297C7C622E7472696767657228226368616E676522293B622E6461746128226368616E676564222C2131297D292E6F6E2822626C75722E6D61736B222C66756E6374696F6E28297B643D632E76616C28297D292E6F';
wwv_flow_api.g_varchar2_table(24) := '6E2822666F6375732E6D61736B222C66756E6374696F6E2862297B21303D3D3D662E73656C6563744F6E466F63757326266128622E746172676574292E73656C65637428297D292E6F6E2822666F6375736F75742E6D61736B222C66756E6374696F6E28';
wwv_flow_api.g_varchar2_table(25) := '297B662E636C65617249664E6F744D61746368262621682E7465737428632E76616C2829292626632E76616C282222297D297D2C67657452656765784D61736B3A66756E6374696F6E28297B666F722876617220613D5B5D2C622C632C662C6E2C643D30';
wwv_flow_api.g_varchar2_table(26) := '3B643C652E6C656E6774683B642B2B2928623D6D2E7472616E736C6174696F6E5B652E6368617241742864295D293F28633D622E7061747465726E2E746F537472696E6728292E7265706C616365282F2E7B317D247C5E2E7B317D2F672C2222292C663D';
wwv_flow_api.g_varchar2_table(27) := '622E6F7074696F6E616C2C0A28623D622E726563757273697665293F28612E7075736828652E636861724174286429292C6E3D7B64696769743A652E6368617241742864292C7061747465726E3A637D293A612E7075736828667C7C623F632B223F223A';
wwv_flow_api.g_varchar2_table(28) := '6329293A612E7075736828652E6368617241742864292E7265706C616365282F5B2D5C2F5C5C5E242A2B3F2E28297C5B5C5D7B7D5D2F672C225C5C24262229293B613D612E6A6F696E282222293B6E262628613D612E7265706C616365286E6577205265';
wwv_flow_api.g_varchar2_table(29) := '67457870282228222B6E2E64696769742B22282E2A222B6E2E64696769742B22293F2922292C22282431293F22292E7265706C616365286E657720526567457870286E2E64696769742C226722292C6E2E7061747465726E29293B72657475726E206E65';
wwv_flow_api.g_varchar2_table(30) := '77205265674578702861297D2C64657374726F794576656E74733A66756E6374696F6E28297B622E6F66662822696E707574206B6579646F776E206B657975702070617374652064726F7020626C757220666F6375736F757420222E73706C6974282220';
wwv_flow_api.g_varchar2_table(31) := '22292E6A6F696E28222E6D61736B202229297D2C76616C3A66756E6374696F6E2861297B76617220633D622E69732822696E70757422293F2276616C223A2274657874223B696628303C617267756D656E74732E6C656E677468297B696628625B635D28';
wwv_flow_api.g_varchar2_table(32) := '29213D3D6129625B635D2861293B0A633D627D656C736520633D625B635D28293B72657475726E20637D2C63616C63756C6174654361726574506F736974696F6E3A66756E6374696F6E28297B76617220613D622E6461746128226D61736B2D70726576';
wwv_flow_api.g_varchar2_table(33) := '6975732D76616C756522297C7C22222C653D632E6765744D61736B656428292C673D632E676574436172657428293B69662861213D3D65297B76617220663D622E6461746128226D61736B2D707265766975732D63617265742D706F7322297C7C302C65';
wwv_flow_api.g_varchar2_table(34) := '3D652E6C656E6774682C643D612E6C656E6774682C6D3D613D302C683D302C6C3D302C6B3B666F72286B3D673B6B3C652626632E6D61736B4469676974506F734D61705B6B5D3B6B2B2B296D2B2B3B666F72286B3D672D313B303C3D6B2626632E6D6173';
wwv_flow_api.g_varchar2_table(35) := '6B4469676974506F734D61705B6B5D3B6B2D2D29612B2B3B666F72286B3D672D313B303C3D6B3B6B2D2D29632E6D61736B4469676974506F734D61705B6B5D2626682B2B3B666F72286B3D662D313B303C3D6B3B6B2D2D29632E6D61736B446967697450';
wwv_flow_api.g_varchar2_table(36) := '6F734D61704F6C645B6B5D26266C2B2B3B673E643F673D31302A653A663E3D67262666213D3D643F632E6D61736B4469676974506F734D61704F6C645B675D7C7C28663D672C673D672D286C2D68292D612C632E6D61736B4469676974506F734D61705B';
wwv_flow_api.g_varchar2_table(37) := '675D262628673D6629293A673E6626260A28673D672B28682D6C292B6D297D72657475726E20677D2C6265686176696F75723A66756E6374696F6E2866297B663D667C7C77696E646F772E6576656E743B632E696E76616C69643D5B5D3B76617220653D';
wwv_flow_api.g_varchar2_table(38) := '622E6461746128226D61736B2D6B6579636F646522293B6966282D313D3D3D612E696E417272617928652C6D2E6279506173734B65797329297B76617220653D632E6765744D61736B656428292C673D632E676574436172657428293B73657454696D65';
wwv_flow_api.g_varchar2_table(39) := '6F75742866756E6374696F6E28297B632E736574436172657428632E63616C63756C6174654361726574506F736974696F6E2829297D2C612E6A4D61736B476C6F62616C732E6B65795374726F6B65436F6D70656E736174696F6E293B632E76616C2865';
wwv_flow_api.g_varchar2_table(40) := '293B632E73657443617265742867293B72657475726E20632E63616C6C6261636B732866297D7D2C6765744D61736B65643A66756E6374696F6E28612C62297B76617220673D5B5D2C643D766F696420303D3D3D623F632E76616C28293A622B22222C6E';
wwv_flow_api.g_varchar2_table(41) := '3D302C683D652E6C656E6774682C713D302C6C3D642E6C656E6774682C6B3D312C723D2270757368222C703D2D312C743D302C793D5B5D2C762C7A3B662E726576657273653F28723D22756E7368696674222C6B3D2D312C763D302C6E3D682D312C713D';
wwv_flow_api.g_varchar2_table(42) := '6C2D312C7A3D66756E6374696F6E28297B72657475726E2D313C0A6E26262D313C717D293A28763D682D312C7A3D66756E6374696F6E28297B72657475726E206E3C682626713C6C7D293B666F722876617220413B7A28293B297B76617220783D652E63';
wwv_flow_api.g_varchar2_table(43) := '6861724174286E292C773D642E6368617241742871292C753D6D2E7472616E736C6174696F6E5B785D3B6966287529772E6D6174636828752E7061747465726E293F28675B725D2877292C752E7265637572736976652626282D313D3D3D703F703D6E3A';
wwv_flow_api.g_varchar2_table(44) := '6E3D3D3D7626266E213D3D702626286E3D702D6B292C763D3D3D702626286E2D3D6B29292C6E2B3D6B293A773D3D3D413F28742D2D2C413D766F69642030293A752E6F7074696F6E616C3F286E2B3D6B2C712D3D6B293A752E66616C6C6261636B3F2867';
wwv_flow_api.g_varchar2_table(45) := '5B725D28752E66616C6C6261636B292C6E2B3D6B2C712D3D6B293A632E696E76616C69642E70757368287B703A712C763A772C653A752E7061747465726E7D292C712B3D6B3B656C73657B696628216129675B725D2878293B773D3D3D783F28792E7075';
wwv_flow_api.g_varchar2_table(46) := '73682871292C712B3D6B293A28413D782C792E7075736828712B74292C742B2B293B6E2B3D6B7D7D643D652E6368617241742876293B68213D3D6C2B317C7C6D2E7472616E736C6174696F6E5B645D7C7C672E707573682864293B673D672E6A6F696E28';
wwv_flow_api.g_varchar2_table(47) := '2222293B632E6D61704D61736B6469676974506F736974696F6E7328672C0A792C6C293B72657475726E20677D2C6D61704D61736B6469676974506F736974696F6E733A66756E6374696F6E28612C622C65297B613D662E726576657273653F612E6C65';
wwv_flow_api.g_varchar2_table(48) := '6E6774682D653A303B632E6D61736B4469676974506F734D61703D7B7D3B666F7228653D303B653C622E6C656E6774683B652B2B29632E6D61736B4469676974506F734D61705B625B655D2B615D3D317D2C63616C6C6261636B733A66756E6374696F6E';
wwv_flow_api.g_varchar2_table(49) := '2861297B76617220683D632E76616C28292C673D68213D3D642C6D3D5B682C612C622C665D2C713D66756E6374696F6E28612C622C63297B2266756E6374696F6E223D3D3D747970656F6620665B615D2626622626665B615D2E6170706C792874686973';
wwv_flow_api.g_varchar2_table(50) := '2C63297D3B7128226F6E4368616E6765222C21303D3D3D672C6D293B7128226F6E4B65795072657373222C21303D3D3D672C6D293B7128226F6E436F6D706C657465222C682E6C656E6774683D3D3D652E6C656E6774682C6D293B7128226F6E496E7661';
wwv_flow_api.g_varchar2_table(51) := '6C6964222C303C632E696E76616C69642E6C656E6774682C5B682C612C622C632E696E76616C69642C665D297D7D3B623D612862293B766172206D3D746869732C643D632E76616C28292C683B653D2266756E6374696F6E223D3D3D747970656F662065';
wwv_flow_api.g_varchar2_table(52) := '3F6528632E76616C28292C766F696420302C622C66293A653B6D2E6D61736B3D0A653B6D2E6F7074696F6E733D663B6D2E72656D6F76653D66756E6374696F6E28297B76617220613D632E676574436172657428293B6D2E6F7074696F6E732E706C6163';
wwv_flow_api.g_varchar2_table(53) := '65686F6C6465722626622E72656D6F7665417474722822706C616365686F6C64657222293B622E6461746128226D61736B2D6D61786C656E67746822292626622E72656D6F76654174747228226D61786C656E67746822293B632E64657374726F794576';
wwv_flow_api.g_varchar2_table(54) := '656E747328293B632E76616C286D2E676574436C65616E56616C2829293B632E73657443617265742861293B72657475726E20627D3B6D2E676574436C65616E56616C3D66756E6374696F6E28297B72657475726E20632E6765744D61736B6564282130';
wwv_flow_api.g_varchar2_table(55) := '297D3B6D2E6765744D61736B656456616C3D66756E6374696F6E2861297B72657475726E20632E6765744D61736B65642821312C61297D3B6D2E696E69743D66756E6374696F6E2864297B643D647C7C21313B663D667C7C7B7D3B6D2E636C6561724966';
wwv_flow_api.g_varchar2_table(56) := '4E6F744D617463683D612E6A4D61736B476C6F62616C732E636C65617249664E6F744D617463683B6D2E6279506173734B6579733D612E6A4D61736B476C6F62616C732E6279506173734B6579733B6D2E7472616E736C6174696F6E3D612E657874656E';
wwv_flow_api.g_varchar2_table(57) := '64287B7D2C612E6A4D61736B476C6F62616C732E7472616E736C6174696F6E2C662E7472616E736C6174696F6E293B0A6D3D612E657874656E642821302C7B7D2C6D2C66293B683D632E67657452656765784D61736B28293B6966286429632E6576656E';
wwv_flow_api.g_varchar2_table(58) := '747328292C632E76616C28632E6765744D61736B65642829293B656C73657B662E706C616365686F6C6465722626622E617474722822706C616365686F6C646572222C662E706C616365686F6C646572293B622E6461746128226D61736B22292626622E';
wwv_flow_api.g_varchar2_table(59) := '6174747228226175746F636F6D706C657465222C226F666622293B643D303B666F7228766172206C3D21303B643C652E6C656E6774683B642B2B297B76617220673D6D2E7472616E736C6174696F6E5B652E6368617241742864295D3B69662867262667';
wwv_flow_api.g_varchar2_table(60) := '2E726563757273697665297B6C3D21313B627265616B7D7D6C2626622E6174747228226D61786C656E677468222C652E6C656E677468292E6461746128226D61736B2D6D61786C656E677468222C2130293B632E64657374726F794576656E747328293B';
wwv_flow_api.g_varchar2_table(61) := '632E6576656E747328293B643D632E676574436172657428293B632E76616C28632E6765744D61736B65642829293B632E73657443617265742864297D7D3B6D2E696E69742821622E69732822696E7075742229297D3B612E6D61736B57617463686572';
wwv_flow_api.g_varchar2_table(62) := '733D7B7D3B76617220643D66756E6374696F6E28297B76617220623D612874686973292C653D7B7D2C663D622E617474722822646174612D6D61736B22293B0A622E617474722822646174612D6D61736B2D726576657273652229262628652E72657665';
wwv_flow_api.g_varchar2_table(63) := '7273653D2130293B622E617474722822646174612D6D61736B2D636C65617269666E6F746D617463682229262628652E636C65617249664E6F744D617463683D2130293B2274727565223D3D3D622E617474722822646174612D6D61736B2D73656C6563';
wwv_flow_api.g_varchar2_table(64) := '746F6E666F6375732229262628652E73656C6563744F6E466F6375733D2130293B6966287028622C662C65292972657475726E20622E6461746128226D61736B222C6E6577206C28746869732C662C6529297D2C703D66756E6374696F6E28622C652C66';
wwv_flow_api.g_varchar2_table(65) := '297B663D667C7C7B7D3B76617220633D612862292E6461746128226D61736B22292C643D4A534F4E2E737472696E676966793B623D612862292E76616C28297C7C612862292E7465787428293B7472797B72657475726E2266756E6374696F6E223D3D3D';
wwv_flow_api.g_varchar2_table(66) := '747970656F662065262628653D65286229292C226F626A65637422213D3D747970656F6620637C7C6428632E6F7074696F6E7329213D3D642866297C7C632E6D61736B213D3D657D63617463682874297B7D7D2C683D66756E6374696F6E2861297B7661';
wwv_flow_api.g_varchar2_table(67) := '7220623D646F63756D656E742E637265617465456C656D656E74282264697622292C643B613D226F6E222B613B643D6120696E20623B647C7C28622E73657441747472696275746528612C0A2272657475726E3B22292C643D2266756E6374696F6E223D';
wwv_flow_api.g_varchar2_table(68) := '3D3D747970656F6620625B615D293B72657475726E20647D3B612E666E2E6D61736B3D66756E6374696F6E28622C64297B643D647C7C7B7D3B76617220653D746869732E73656C6563746F722C633D612E6A4D61736B476C6F62616C732C683D632E7761';
wwv_flow_api.g_varchar2_table(69) := '746368496E74657276616C2C633D642E7761746368496E707574737C7C632E7761746368496E707574732C743D66756E6374696F6E28297B6966287028746869732C622C64292972657475726E20612874686973292E6461746128226D61736B222C6E65';
wwv_flow_api.g_varchar2_table(70) := '77206C28746869732C622C6429297D3B612874686973292E656163682874293B6526262222213D3D65262663262628636C656172496E74657276616C28612E6D61736B57617463686572735B655D292C612E6D61736B57617463686572735B655D3D7365';
wwv_flow_api.g_varchar2_table(71) := '74496E74657276616C2866756E6374696F6E28297B6128646F63756D656E74292E66696E642865292E656163682874297D2C6829293B72657475726E20746869737D3B612E666E2E6D61736B65643D66756E6374696F6E2861297B72657475726E207468';
wwv_flow_api.g_varchar2_table(72) := '69732E6461746128226D61736B22292E6765744D61736B656456616C2861297D3B612E666E2E756E6D61736B3D66756E6374696F6E28297B636C656172496E74657276616C28612E6D61736B57617463686572735B746869732E73656C6563746F725D29';
wwv_flow_api.g_varchar2_table(73) := '3B0A64656C65746520612E6D61736B57617463686572735B746869732E73656C6563746F725D3B72657475726E20746869732E656163682866756E6374696F6E28297B76617220623D612874686973292E6461746128226D61736B22293B622626622E72';
wwv_flow_api.g_varchar2_table(74) := '656D6F766528292E72656D6F76654461746128226D61736B22297D297D3B612E666E2E636C65616E56616C3D66756E6374696F6E28297B72657475726E20746869732E6461746128226D61736B22292E676574436C65616E56616C28297D3B612E617070';
wwv_flow_api.g_varchar2_table(75) := '6C79446174614D61736B3D66756E6374696F6E2862297B623D627C7C612E6A4D61736B476C6F62616C732E6D61736B456C656D656E74733B286220696E7374616E63656F6620613F623A61286229292E66696C74657228612E6A4D61736B476C6F62616C';
wwv_flow_api.g_varchar2_table(76) := '732E646174614D61736B41747472292E656163682864297D3B683D7B6D61736B456C656D656E74733A22696E7075742C74642C7370616E2C646976222C646174614D61736B417474723A222A5B646174612D6D61736B5D222C646174614D61736B3A2130';
wwv_flow_api.g_varchar2_table(77) := '2C7761746368496E74657276616C3A3330302C7761746368496E707574733A21302C6B65795374726F6B65436F6D70656E736174696F6E3A31302C757365496E7075743A212F4368726F6D655C2F5B322D345D5B302D395D7C53616D73756E6742726F77';
wwv_flow_api.g_varchar2_table(78) := '7365722F2E746573742877696E646F772E6E6176696761746F722E757365724167656E742926260A682822696E70757422292C7761746368446174614D61736B3A21312C6279506173734B6579733A5B392C31362C31372C31382C33362C33372C33382C';
wwv_flow_api.g_varchar2_table(79) := '33392C34302C39315D2C7472616E736C6174696F6E3A7B303A7B7061747465726E3A2F5C642F7D2C393A7B7061747465726E3A2F5C642F2C6F7074696F6E616C3A21307D2C2223223A7B7061747465726E3A2F5C642F2C7265637572736976653A21307D';
wwv_flow_api.g_varchar2_table(80) := '2C413A7B7061747465726E3A2F5B612D7A412D5A302D395D2F7D2C533A7B7061747465726E3A2F5B612D7A412D5A5D2F7D7D7D3B612E6A4D61736B476C6F62616C733D612E6A4D61736B476C6F62616C737C7C7B7D3B683D612E6A4D61736B476C6F6261';
wwv_flow_api.g_varchar2_table(81) := '6C733D612E657874656E642821302C7B7D2C682C612E6A4D61736B476C6F62616C73293B682E646174614D61736B2626612E6170706C79446174614D61736B28293B736574496E74657276616C2866756E6374696F6E28297B612E6A4D61736B476C6F62';
wwv_flow_api.g_varchar2_table(82) := '616C732E7761746368446174614D61736B2626612E6170706C79446174614D61736B28297D2C682E7761746368496E74657276616C297D2C77696E646F772E6A51756572792C77696E646F772E5A6570746F293B0A';
null;
end;
/
begin
wwv_flow_api.create_plugin_file(
 p_id=>wwv_flow_api.id(20929113941924266744)
,p_plugin_id=>wwv_flow_api.id(20929074087395259260)
,p_file_name=>'jquery.mask.min.js'
,p_mime_type=>'text/javascript'
,p_file_charset=>'utf-8'
,p_file_content=>wwv_flow_api.varchar2_to_blob(wwv_flow_api.g_varchar2_table)
);
end;
/
begin
wwv_flow_api.import_end(p_auto_install_sup_obj => nvl(wwv_flow_application_install.get_auto_install_sup_obj, false), p_is_component_import => true);
commit;
end;
/
set verify on feedback on define on
prompt  ...done
